
(_installation)=
# Installation

The recommended way to install `skretrieval` is through `conda`

    conda install -c conda-forge -c usask-arg skretrieval

Wheels are also made available through `pip`

    pip install skretrieval


# Nightly Builds

The latest nightly version of skretrieval is made available through::

    conda install -c usask-arg-nightly -c conda-forge skretrieval

# Supported Platforms
|   | macOS Intel | macOS Apple Silicon | Windows 64bit | manylinux x86_64 |
|---------------|----|-----|-----|-----|
| CPython 3.10  | ✅ | ✅  | ✅  | ✅  |
| CPython 3.11  | ✅ | ✅  | ✅  | ✅  |
| CPython 3.12  | ✅ | ✅  | ✅  | ✅  |
